==> haskell-juicypixels-3.3.5-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-juicypixels.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 JuicyPixels
version:              3.3.5
visibility:           public
id:                   JuicyPixels-3.3.5-CtX4STN02adGgF8rDkdyp5
key:                  JuicyPixels-3.3.5-CtX4STN02adGgF8rDkdyp5
license:              BSD-3-Clause
maintainer:           vincent.berthoux@gmail.com
author:               Vincent Berthoux
stability:            Stable
homepage:             https://github.com/Twinside/Juicy.Pixels
synopsis:
    Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)

description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>

    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.

category:             Codec, Graphics, Image
abi:                  c7a4bcdaa5b327189568a46b2541c8dc
exposed:              True
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.ColorQuant
    Codec.Picture.Gif Codec.Picture.Gif.Internal.LZW
    Codec.Picture.Gif.Internal.LZWEncoding Codec.Picture.HDR
    Codec.Picture.Jpg Codec.Picture.Jpg.Internal.Common
    Codec.Picture.Jpg.Internal.DefaultTable
    Codec.Picture.Jpg.Internal.FastDct
    Codec.Picture.Jpg.Internal.FastIdct
    Codec.Picture.Jpg.Internal.Metadata
    Codec.Picture.Jpg.Internal.Progressive
    Codec.Picture.Jpg.Internal.Types Codec.Picture.Metadata
    Codec.Picture.Metadata.Exif Codec.Picture.Png
    Codec.Picture.Png.Internal.Export
    Codec.Picture.Png.Internal.Metadata Codec.Picture.Png.Internal.Type
    Codec.Picture.Saving Codec.Picture.Tga Codec.Picture.Tiff
    Codec.Picture.Tiff.Internal.Metadata
    Codec.Picture.Tiff.Internal.Types Codec.Picture.Types

hidden-modules:
    Codec.Picture.BitWriter Codec.Picture.InternalHelper
    Codec.Picture.VectorByteConversion

import-dirs:          /usr/lib/ghc-9.0.1/site-local/JuicyPixels-3.3.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/JuicyPixels-3.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/JuicyPixels-3.3.5
hs-libraries:         HSJuicyPixels-3.3.5-CtX4STN02adGgF8rDkdyp5
include-dirs:         /usr/lib/ghc-9.0.1/site-local/JuicyPixels-3.3.5/include
depends:
    base-4.15.0.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 deepseq-1.4.5.0 mtl-2.2.2
    primitive-0.7.1.0-Ebr02v1g7AH85oov8ub0Ue transformers-0.5.6.2
    vector-0.12.3.0-GCUXSGuKlli3UlEh84h4Y9
    zlib-0.6.2.3-4iAWTatWHCRH6N3xUb7uPR

haddock-interfaces:   /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html:         /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-juicypixels-3.3.5-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-juicypixels.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 JuicyPixels
version:              3.3.5
visibility:           public
id:                   JuicyPixels-3.3.5-6htRCzsMG9E8H5yk97w7uU
key:                  JuicyPixels-3.3.5-6htRCzsMG9E8H5yk97w7uU
license:              BSD-3-Clause
maintainer:           vincent.berthoux@gmail.com
author:               Vincent Berthoux
stability:            Stable
homepage:             https://github.com/Twinside/Juicy.Pixels
synopsis:
    Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)

description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>

    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.

category:             Codec, Graphics, Image
abi:                  9fdddd7cc24b8fc14d7ba78d523e640c
exposed:              True
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.ColorQuant
    Codec.Picture.Gif Codec.Picture.Gif.Internal.LZW
    Codec.Picture.Gif.Internal.LZWEncoding Codec.Picture.HDR
    Codec.Picture.Jpg Codec.Picture.Jpg.Internal.Common
    Codec.Picture.Jpg.Internal.DefaultTable
    Codec.Picture.Jpg.Internal.FastDct
    Codec.Picture.Jpg.Internal.FastIdct
    Codec.Picture.Jpg.Internal.Metadata
    Codec.Picture.Jpg.Internal.Progressive
    Codec.Picture.Jpg.Internal.Types Codec.Picture.Metadata
    Codec.Picture.Metadata.Exif Codec.Picture.Png
    Codec.Picture.Png.Internal.Export
    Codec.Picture.Png.Internal.Metadata Codec.Picture.Png.Internal.Type
    Codec.Picture.Saving Codec.Picture.Tga Codec.Picture.Tiff
    Codec.Picture.Tiff.Internal.Metadata
    Codec.Picture.Tiff.Internal.Types Codec.Picture.Types

hidden-modules:
    Codec.Picture.BitWriter Codec.Picture.InternalHelper
    Codec.Picture.VectorByteConversion

import-dirs:          /usr/lib/ghc-9.0.1/site-local/JuicyPixels-3.3.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/JuicyPixels-3.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/JuicyPixels-3.3.5
hs-libraries:         HSJuicyPixels-3.3.5-6htRCzsMG9E8H5yk97w7uU
include-dirs:         /usr/lib/ghc-9.0.1/site-local/JuicyPixels-3.3.5/include
depends:
    base-4.15.0.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 deepseq-1.4.5.0 mtl-2.2.2
    primitive-0.7.1.0-KvjkSKnzuhtan9loX8sTh transformers-0.5.6.2
    vector-0.12.3.0-5y94DJOg9cG5Wgh0YNjnNz
    zlib-0.6.2.3-HIee7wGDSdNCsfD2pJBTDB

haddock-interfaces:   /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html:         /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
